==> ejc-jltest-api-3.0.0-20240319.032028-81-sources.jar: com/ejianc/business/jltest/margin/vo/AssessCashDetailSumVO.java <==
package com.ejianc.business.jltest.margin.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;


/**
 * 考核兑现汇总明细表
 * 
 * @author generator
 * 
 */
public class AssessCashDetailSumVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    


    private String sumName; // 节点阶段
    private BigDecimal sumMny; // 项目分配兑现利润(万元)
    private String memo; // 备注
    private Long assessId; // 考核兑现审批表Id
    private Long cashSumId; // 兑现计算汇总单据
    private String cashSumName; // 兑现计算汇总单据名称
    private String cashSumCode; // 兑现计算汇总单据编码
    


    public String getSumName() {
        return sumName;
    }

    public void setSumName(String sumName) {
        this.sumName = sumName;
    }
    public BigDecimal getSumMny() {
        return sumMny;
    }

    public void setSumMny(BigDecimal sumMny) {
        this.sumMny = sumMny;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getAssessId() {
        return assessId;
    }

    public void setAssessId(Long assessId) {
        this.assessId = assessId;
    }
    public Long getCashSumId() {
        return cashSumId;
    }

    public void setCashSumId(Long cashSumId) {
        this.cashSumId = cashSumId;
    }
    public String getCashSumName() {
        return cashSumName;
    }

    public void setCashSumName(String cashSumName) {
        this.cashSumName = cashSumName;
    }
    public String getCashSumCode() {
        return cashSumCode;
    }

    public void setCashSumCode(String cashSumCode) {
        this.cashSumCode = cashSumCode;
    }
    
}

==> ejc-jltest-api-3.0.0-20240320.023035-84-sources.jar: com/ejianc/business/jltest/margin/vo/AssessCashDetailSumVO.java <==
package com.ejianc.business.jltest.margin.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;


/**
 * 考核兑现汇总明细表
 *
 * @author generator
 *
 */
public class AssessCashDetailSumVO extends BaseVO {
    private static final long serialVersionUID = 1L;



    private String sumName; // 节点阶段
    private BigDecimal sumMny; // 项目分配兑现利润(万元)
    private String memo; // 备注
    private Long assessId; // 考核兑现审批表Id
    private Long cashSumId; // 兑现计算汇总单据
    private String cashSumName; // 兑现计算汇总单据名称
    private String cashSumCode; // 兑现计算汇总单据编码



    public String getSumName() {
        return sumName;
    }

    public void setSumName(String sumName) {
        this.sumName = sumName;
    }
    public BigDecimal getSumMny() {
        return sumMny;
    }

    public void setSumMny(BigDecimal sumMny) {
        this.sumMny = sumMny;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getAssessId() {
        return assessId;
    }

    public void setAssessId(Long assessId) {
        this.assessId = assessId;
    }
    public Long getCashSumId() {
        return cashSumId;
    }
    @ReferSerialTransfer(referCode = "cash-sum-ref")

    public void setCashSumId(Long cashSumId) {
        this.cashSumId = cashSumId;
    }
    @ReferDeserialTransfer
    public String getCashSumName() {
        return cashSumName;
    }

    public void setCashSumName(String cashSumName) {
        this.cashSumName = cashSumName;
    }
    public String getCashSumCode() {
        return cashSumCode;
    }

    public void setCashSumCode(String cashSumCode) {
        this.cashSumCode = cashSumCode;
    }

}
